<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://rextheme.com
 * @since      1.0.0
 *
 * @package    Rex_Product_Feed
 * @subpackage Rex_Product_Feed/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Rex_Product_Feed
 * @subpackage Rex_Product_Feed/admin
 * @author     RexTheme <info@rextheme.com>
 */
class Rex_Product_Feed_Admin {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;


    /**
     * Metabox instance of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      object    $metabox    The current metabox of this plugin.
     */
    private $cpt;

    /**
     * Metabox instance of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      object    $metabox    The current metabox of this plugin.
     */
    private $metabox;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of this plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct( $plugin_name, $version ) {

        $this->plugin_name = $plugin_name;
        $this->version     = $version;
        $this->cpt         = new Rex_Product_CPT;
        $this->metabox     = new Rex_Product_Metabox;

    }

    /**
     * Register the stylesheets for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_styles($hook) {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Rex_Product_Feed_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Rex_Product_Feed_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        $screen = get_current_screen();
//        if( ($hook != 'post.php' && $hook != 'post-new.php') || ($hook != 'feed_page_category_mapping' ) ){
//            return;
//        }
//
        if( ($hook === 'edit.php' ) ){
            return;
        }

        if ( $screen->post_type === 'product-feed' || $screen->id === 'product-feed_page_category_mapping' || $screen->id === 'product-feed_page_bwfm-dashboard') {
            wp_enqueue_style( 'materialize-icons', 'https://fonts.googleapis.com/icon?family=Material+Icons', array(), $this->version, 'all' );
            wp_enqueue_style( 'materialize-css', plugin_dir_url( __FILE__ ) . 'css/materialize.min.css', array(), $this->version, 'all' );
            wp_enqueue_style( 'easy-auto', 'https://cdnjs.cloudflare.com/ajax/libs/easy-autocomplete/1.3.5/easy-autocomplete.min.css', array(), $this->version, 'all' );
            wp_enqueue_style( 'font-awesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css', array(), $this->version, 'all' );
            wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/rex-product-feed-admin.css', array(), $this->version, 'all' );

        }
    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts($hook) {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Rex_Product_Feed_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Rex_Product_Feed_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */


//        if( $hook != 'post.php' && $hook != 'post-new.php' && $hook != 'product-feed_page_category_mapping' && $hook != 'product-feed_page_user_on_boarding' ){
//            return;
//        }

        $screen = get_current_screen();
        if( ($hook === 'edit.php' ) ){
            return;
        }


        if ( $screen->post_type === 'product-feed' || $screen->id === 'product-feed_page_category_mapping' || $screen->id === 'product-feed_page_bwfm-dashboard' ) {
            wp_enqueue_script( 'materialize-js', plugin_dir_url( __FILE__ ) . 'js/materialize.min.js', array( 'jquery' ), $this->version, false );
            wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/rex-product-feed-admin.js', array( 'jquery' ), $this->version, false );
        }
        wp_enqueue_script( 'easy', plugin_dir_url( __FILE__ ) . 'js/wp-jquery.easy-autocomplete.js', array( 'jquery' ), $this->version, false );
        wp_enqueue_script( 'category-map', plugin_dir_url( __FILE__ ) . 'js/category-mapper.js', array( 'jquery' ), $this->version, false );
    }

    /**
     * Remove a previously enqueued script by libraries
     * for the admin area.
     *
     * @since    1.0.0
     */
    public function dequeue_scripts($hook) {

        $screen = get_current_screen();
        if ( $screen->post_type != 'product-feed' ) {
            // wp_dequeue_script( 'cmb2-scripts' );
            // wp_dequeue_script( 'cmb2-conditionals' );
            // wp_dequeue_script( 'wp-ajax-helper' );

        }

    }


    /**
     * Admin Notices
     *
     * @since    1.2.7
     */
    public function bwfm_admin_notices() {
        $total_feed = get_option('rex_total_feed');
        $show_notice = get_option('rex_bwfm_notification_status');

        if ($total_feed == 'yes' AND $show_notice != 'no') {
            ?>
            <div class="notice notice-info bwfm-review-notice" style="position: relative">
                <p><strong style="font-weight: bold">Hey, I noticed you just created a new feed with 50 products using WC product feed manager – that’s awesome! Could you please do me a
                        BIG favor and give it a 5-star rating on WordPress? Just to help us spread the word and boost our motivation.<br>~ Lincoln </strong></p>

                <ul>
                    <li>
                        <a href="https://wordpress.org/support/plugin/best-woocommerce-feed/reviews/#new-post" target="_blank" class="" style="font-weight: bold">Ok, you deserve it</a>
                    </li>
                    <li>
                        <a href="#" class="stop-bwfm-notice" style="font-weight: bold">Nope, maybe later</a>
                    </li>
                    <li>
                        <a href="#" class="stop-bwfm-notice" style="font-weight: bold">I already did</a>
                    </li>
                </ul>
                <button type="button" class="notice-dismiss bwfm-dismiss-notice"><span class="screen-reader-text">' . __( 'Dismiss this notice.', 'rex-product-feed' ) . '</span></button>
            </div>
        <?php }

        $activation_time = get_option('rex_bwfm_first_installation');
//            $user_review  =
        $current_time = time();
        $notice_start = 1209600;
        $interval   = ($current_time - $activation_time)>$notice_start ? true : false;

        if ($interval AND $show_notice !='no') {?>
            <div class="notice notice-info bwfm-review-notice" style="position: relative">
                <p><strong style="font-weight: bold">Hey, I noticed you are using WC product feed manager for over two weeks – that’s awesome! Could you please do me a BIG favor and give it a 5-star rating on WordPress? Just to help us spread the word and boost our motivation.<br>~ Lincoln </strong></p>
                <ul>
                    <li>
                        <a href="https://wordpress.org/support/plugin/best-woocommerce-feed/reviews/#new-post" target="_blank" class="" style="font-weight: bold">Ok, you deserve it</a>
                    </li>
                    <li>
                        <a href="#" class="stop-bwfm-notice" style="font-weight: bold">Nope, maybe later</a>
                    </li>
                    <li>
                        <a href="#" class="stop-bwfm-notice" style="font-weight: bold">I already did</a>
                    </li>
                </ul>
                <button type="button" class="notice-dismiss bwfm-dismiss-notice"><span class="screen-reader-text">' . __( 'Dismiss this notice.', 'rex-product-feed' ) . '</span></button>
            </div>

        <?php }
    }



    /**
     * Register CPT for the Plugin
     *
     * @since    1.0.0
     */
    public function register_cpt() {
        $this->cpt->register();
    }

    /**
     * Remove Bulk Edit for Feed
     *
     * @since    1.0.0
     */
    public function remove_bulk_edit( $actions ){
        unset( $actions['edit'] );
        return $actions;
    }

    /**
     * Remove Quick Edit for Feed
     *
     * @since    1.0.0
     */
    public function remove_quick_edit( $actions ){
        // Abort if the post type is not "books"
        if ( ! is_post_type_archive( 'product-feed' ) ) {
            return $actions;
        }

        // Remove the Quick Edit link
        if ( isset( $actions['inline hide-if-no-js'] ) ) {
            unset( $actions['inline hide-if-no-js'] );
        }

        // Return the set of links without Quick Edit
        return $actions;
    }

    /**
     * Register All the Metaboxes for the admin area.
     *
     * @since    1.0.0
     */
    public function register_metaboxes() {
        $this->metabox->register();
    }


    /**
     * Register Plugin Admin Pages
     *
     * @since    1.0.0
     */
    public function load_admin_pages() {
        add_menu_page( __( 'Product Feed', 'rex-product-feed' ), __( 'Product Feed', 'rex-product-feed' ), 'manage_options', 'product-feed', null, PLUGIN_DIR_URL . 'admin/icon/icon.png', 5 );
        add_submenu_page('product-feed', 'Add New Feed', 'Add New Feed', 'manage_options', 'post-new.php?post_type=product-feed');
        add_submenu_page('product-feed', __('Category Mapping', 'rex-product-feed'), __('Category Mapping', 'rex-product-feed'), 'manage_options', 'category_mapping',  __CLASS__ .'::category_mapping');
        add_submenu_page('product-feed', __('Dashboard', 'rex-product-feed'), __('Dashboard', 'rex-product-feed'), 'manage_options', 'bwfm-dashboard',  __CLASS__ .'::user_dashboard');
    }

    public function category_mapping(){
        require plugin_dir_path(__FILE__) . '/partials/category_mapping.php';
    }


    public function user_dashboard(){
        require plugin_dir_path(__FILE__) . '/partials/on_boarding.php';
    }

}
